@@ -10,11 +10,11 @@ Crypt::LE - Let's Encrypt API interfacing module.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -335,7 +335,6 @@ sub generate_csr {
     return $self->_status(INVALID_DATA, "No domains provided.") unless @list;
     my $rsa = Crypt::OpenSSL::RSA->generate_key($keysize);
     my $csr = Crypt::OpenSSL::PKCS10->new_from_rsa($rsa);
-    # https://rt.cpan.org/Public/Bug/Display.html?id=111829 workaround
     $csr->set_subject("/CN=$list[0]");
     if (@list > 1) {
         $csr->add_ext(NID_subject_alt_name, join(",", map {"DNS:$_"} @list));
@@ -635,7 +634,7 @@ For example, you can create a module like this to handle the challenge:
  
  1;
 
-You can then use it as shown below:
+You can then use it as shown below from your program:
 
  use Crypt::LE;
  use Crypt::LE::Challenge::Simple;
@@ -645,6 +644,10 @@ You can then use it as shown below:
  ...
  $le->accept_challenge($simple_challenge);
  
+Or you can use it with the provided client (le.pl), by adding a parameter to its command line:
+
+ --handle-with Crypt::LE::Challenge::Simple
+ 
 I<If you create a plugin handling challenges for Crypt::LE, please use Crypt::LE::Challenge:: namespace, so it would be easier to
 find those.> For a boilerplate of the plugin handling the challenges, see L<Crypt::LE::Challenge::Simple>.
  
@@ -799,7 +802,7 @@ sub request_issuer_certificate {
 # API Workflow helpers
 #====================================================================================================
 
-=head1 METHODS (COMMON GETTERS)
+=head1 METHODS (OTHER)
 
 The following methods are the common getters you can use to get more details about the outcome of the workflow run and return some retrieved data, such as
 registration info and certificates for your domains.
