@@ -9,11 +9,13 @@ use Crypt::LE ':errors';
 sub info { print shift, "\n" }
 sub bail { &info; exit 255 }
 
-my ($account_key, $csr, $csr_key, $domains, $challenge_path, $crt, $live, $generate_missing, $generate_only, $verified, $debug, $help);
+my $VERSION = '0.03';
+
+my ($account_key, $csr, $csr_key, $domains, $challenge_path, $crt, $live, $generate_missing, $generate_only, $handle_with, $handle_as, $verified, $debug, $help);
 
 GetOptions ("key=s" => \$account_key, "csr=s" => \$csr, "csr-key=s" => \$csr_key, "domains=s" => \$domains, "path=s" => \$challenge_path,
-            "crt=s" => \$crt, "generate-missing" => \$generate_missing, "generate-only" => \$generate_only, 
-	    "live" => \$live, "debug" => \$debug, "verified" => \$verified, "help" => \$help);
+            "crt=s" => \$crt, "generate-missing" => \$generate_missing, "generate-only" => \$generate_only, "handle-with=s" => \$handle_with,
+	    "handle-as=s" => \$handle_as, "live" => \$live, "debug" => \$debug, "verified" => \$verified, "help" => \$help);
 
 my $usage = <<EOF;
 
@@ -24,22 +26,24 @@ Note: by default a staging server is used, which does not provide trusted certif
 
 Available parameters:
 
- key <file>                 - Your account key file.
- csr <file>                 - Your CSR file.
- csr-key <file>             - Key for your CSR (only mandatory if CSR is missing and to be generated).
- domains <list>             - Domains as comma-separated list (only mandatory if CSR is missing).
- path <absolute path>       - Path to local .well-known/acme-challenge/ to drop required challenge files into (optional).
- generate-missing           - Generate missing files (key, csr and csr-key).
- generate-only              - Generate a new key and/or CSR if they are missing and then exit.
- crt <file>                 - Name for the domain certificate file.
- verified                   - Skip challenge verification steps (request/accept/verify). Use only if domains have been already verified recently.
- live                       - Connect to a live server instead of staging.
- debug                      - Print out debug messages.
- help                       - This screen.
+ key <file>                    - Your account key file.
+ csr <file>                    - Your CSR file.
+ csr-key <file>                - Key for your CSR (only mandatory if CSR is missing and to be generated).
+ domains <list>                - Domains as comma-separated list (only mandatory if CSR is missing).
+ path <absolute path>          - Path to local .well-known/acme-challenge/ to drop required challenge files into (optional).
+ handle-with <Some::Module>    - Module name to handle challenges with (optional).
+ handle-as <http|dns|tls|...>  - Type of challenge to request, by default 'http' (optional).
+ generate-missing              - Generate missing files (key, csr and csr-key).
+ generate-only                 - Generate a new key and/or CSR if they are missing and then exit.
+ crt <file>                    - Name for the domain certificate file.
+ verified                      - Skip challenge verification steps (request/accept/verify). Use only if domains have been already verified recently.
+ live                          - Connect to a live server instead of staging.
+ debug                         - Print out debug messages.
+ help                          - This screen.
 
 EOF
 
-info "\nCrypt::LE client started.\n";
+info "\nCrypt::LE client v$VERSION started.\n";
 
 bail $usage if $help;
 
@@ -61,6 +65,17 @@ if ($challenge_path) {
     bail "Path to save challenge files into should be a writable directory" unless (-d $challenge_path and -w _);
 }
 
+my $handler;
+$handle_as = $handle_as ? lc($handle_as) : 'http';
+
+if ($handle_with) {
+    eval "use $handle_with;";
+    bail "Cannot use the module to handle challenges with." if $@;
+    $handler = new $handle_with;
+    my $method = 'handle_challenge_' . $handle_as;
+    bail "Module to handle challenges does not seem to support the challenge type of '$handle_as'." unless $handler->can($method);
+}
+
 # Begin work
 
 my $le = Crypt::LE->new(debug => $debug, live => $live);
@@ -93,7 +108,7 @@ bail $le->error_details if $le->register;
 $le->accept_tos(); # No need to check explicitly for tos_changed() - Crypt::LE will handle that for you.
 unless ($verified) {
     bail $le->error_details if $le->request_challenge();
-    bail $le->error_details if $le->accept_challenge(\&process_challenge);
+    bail $le->error_details if $le->accept_challenge($handler ? $handler : \&process_challenge, $handle_as);
     bail $le->error_details if $le->verify_challenge;
 }
 info "Requesting domain certificate";
